@@ -1019,22 +1019,23 @@ contains
     end do
     return
   end function randperm
-
+  
   subroutine set_random_seed
     ! Use time stamp to init the random number generator.  For many f95 compilers this is done
     ! using the intrisic subroutine random_seed() but this behavior isn't enforced by the 
     ! standard so this function give a "universal" method of seeding the RNG that should work on
     ! any f95 standard complying compiler.
     implicit none
-    integer :: idate(8)
-    integer, allocatable :: iseed(:)
-    call date_and_time(VALUES=idate)
-    allocate( iseed(8) )
-    iseed = idate(8)
-    call random_seed(PUT=iseed)
-    deallocate ( iseed )  
+    integer :: i, n, clock
+    integer, allocatable :: seed(:)          
+    call random_seed(size=n)
+    allocate( seed(n) )          
+    call system_clock(COUNT=clock)          
+    seed = clock + 37 * (/ (i - 1, i = 1, n) /)
+    call random_seed(PUT=seed)          
+    deallocate( seed )
   end subroutine set_random_seed
-  
+
 end module DE_mod
 
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
